@@ -19,10 +19,6 @@ impl Coord {
     }
   }
 
-  pub fn distance(&self, other: &Self) -> i32 {
-    (self.x - other.x).abs() + (self.y - other.y).abs()
-  }
-
   pub fn matches(&self, x: i32, y: i32) -> bool {
     self.x == x && self.y == y
   }
